# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatascanArgs', 'Datascan']

@pulumi.input_type
class DatascanArgs:
    def __init__(__self__, *,
                 data: pulumi.Input['DatascanDataArgs'],
                 data_scan_id: pulumi.Input[str],
                 execution_spec: pulumi.Input['DatascanExecutionSpecArgs'],
                 location: pulumi.Input[str],
                 data_profile_spec: Optional[pulumi.Input['DatascanDataProfileSpecArgs']] = None,
                 data_quality_spec: Optional[pulumi.Input['DatascanDataQualitySpecArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Datascan resource.
        :param pulumi.Input['DatascanDataArgs'] data: The data source for DataScan.
               Structure is documented below.
        :param pulumi.Input[str] data_scan_id: DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
        :param pulumi.Input['DatascanExecutionSpecArgs'] execution_spec: DataScan execution settings.
               Structure is documented below.
        :param pulumi.Input[str] location: The location where the data scan should reside.
        :param pulumi.Input['DatascanDataProfileSpecArgs'] data_profile_spec: DataProfileScan related setting.
               Structure is documented below.
        :param pulumi.Input['DatascanDataQualitySpecArgs'] data_quality_spec: DataQualityScan related setting.
               Structure is documented below.
        :param pulumi.Input[str] description: Description of the scan.
        :param pulumi.Input[str] display_name: User friendly display name.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: User-defined labels for the scan. A list of key->value pairs.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        pulumi.set(__self__, "data", data)
        pulumi.set(__self__, "data_scan_id", data_scan_id)
        pulumi.set(__self__, "execution_spec", execution_spec)
        pulumi.set(__self__, "location", location)
        if data_profile_spec is not None:
            pulumi.set(__self__, "data_profile_spec", data_profile_spec)
        if data_quality_spec is not None:
            pulumi.set(__self__, "data_quality_spec", data_quality_spec)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter
    def data(self) -> pulumi.Input['DatascanDataArgs']:
        """
        The data source for DataScan.
        Structure is documented below.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: pulumi.Input['DatascanDataArgs']):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter(name="dataScanId")
    def data_scan_id(self) -> pulumi.Input[str]:
        """
        DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
        """
        return pulumi.get(self, "data_scan_id")

    @data_scan_id.setter
    def data_scan_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "data_scan_id", value)

    @property
    @pulumi.getter(name="executionSpec")
    def execution_spec(self) -> pulumi.Input['DatascanExecutionSpecArgs']:
        """
        DataScan execution settings.
        Structure is documented below.
        """
        return pulumi.get(self, "execution_spec")

    @execution_spec.setter
    def execution_spec(self, value: pulumi.Input['DatascanExecutionSpecArgs']):
        pulumi.set(self, "execution_spec", value)

    @property
    @pulumi.getter
    def location(self) -> pulumi.Input[str]:
        """
        The location where the data scan should reside.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: pulumi.Input[str]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="dataProfileSpec")
    def data_profile_spec(self) -> Optional[pulumi.Input['DatascanDataProfileSpecArgs']]:
        """
        DataProfileScan related setting.
        Structure is documented below.
        """
        return pulumi.get(self, "data_profile_spec")

    @data_profile_spec.setter
    def data_profile_spec(self, value: Optional[pulumi.Input['DatascanDataProfileSpecArgs']]):
        pulumi.set(self, "data_profile_spec", value)

    @property
    @pulumi.getter(name="dataQualitySpec")
    def data_quality_spec(self) -> Optional[pulumi.Input['DatascanDataQualitySpecArgs']]:
        """
        DataQualityScan related setting.
        Structure is documented below.
        """
        return pulumi.get(self, "data_quality_spec")

    @data_quality_spec.setter
    def data_quality_spec(self, value: Optional[pulumi.Input['DatascanDataQualitySpecArgs']]):
        pulumi.set(self, "data_quality_spec", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the scan.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        User friendly display name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        User-defined labels for the scan. A list of key->value pairs.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _DatascanState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 data: Optional[pulumi.Input['DatascanDataArgs']] = None,
                 data_profile_results: Optional[pulumi.Input[Sequence[pulumi.Input['DatascanDataProfileResultArgs']]]] = None,
                 data_profile_spec: Optional[pulumi.Input['DatascanDataProfileSpecArgs']] = None,
                 data_quality_results: Optional[pulumi.Input[Sequence[pulumi.Input['DatascanDataQualityResultArgs']]]] = None,
                 data_quality_spec: Optional[pulumi.Input['DatascanDataQualitySpecArgs']] = None,
                 data_scan_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 execution_spec: Optional[pulumi.Input['DatascanExecutionSpecArgs']] = None,
                 execution_statuses: Optional[pulumi.Input[Sequence[pulumi.Input['DatascanExecutionStatusArgs']]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 uid: Optional[pulumi.Input[str]] = None,
                 update_time: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Datascan resources.
        :param pulumi.Input[str] create_time: The time when the scan was created.
        :param pulumi.Input['DatascanDataArgs'] data: The data source for DataScan.
               Structure is documented below.
        :param pulumi.Input[Sequence[pulumi.Input['DatascanDataProfileResultArgs']]] data_profile_results: The result of the data profile scan.
               Structure is documented below.
        :param pulumi.Input['DatascanDataProfileSpecArgs'] data_profile_spec: DataProfileScan related setting.
               Structure is documented below.
        :param pulumi.Input[Sequence[pulumi.Input['DatascanDataQualityResultArgs']]] data_quality_results: The result of the data quality scan.
               Structure is documented below.
        :param pulumi.Input['DatascanDataQualitySpecArgs'] data_quality_spec: DataQualityScan related setting.
               Structure is documented below.
        :param pulumi.Input[str] data_scan_id: DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
        :param pulumi.Input[str] description: Description of the scan.
        :param pulumi.Input[str] display_name: User friendly display name.
        :param pulumi.Input['DatascanExecutionSpecArgs'] execution_spec: DataScan execution settings.
               Structure is documented below.
        :param pulumi.Input[Sequence[pulumi.Input['DatascanExecutionStatusArgs']]] execution_statuses: Status of the data scan execution.
               Structure is documented below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: User-defined labels for the scan. A list of key->value pairs.
        :param pulumi.Input[str] location: The location where the data scan should reside.
        :param pulumi.Input[str] name: The name of the field.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        :param pulumi.Input[str] state: Current state of the DataScan.
        :param pulumi.Input[str] type: The field data type.
        :param pulumi.Input[str] uid: System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.
        :param pulumi.Input[str] update_time: The time when the scan was last updated.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if data_profile_results is not None:
            pulumi.set(__self__, "data_profile_results", data_profile_results)
        if data_profile_spec is not None:
            pulumi.set(__self__, "data_profile_spec", data_profile_spec)
        if data_quality_results is not None:
            pulumi.set(__self__, "data_quality_results", data_quality_results)
        if data_quality_spec is not None:
            pulumi.set(__self__, "data_quality_spec", data_quality_spec)
        if data_scan_id is not None:
            pulumi.set(__self__, "data_scan_id", data_scan_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if execution_spec is not None:
            pulumi.set(__self__, "execution_spec", execution_spec)
        if execution_statuses is not None:
            pulumi.set(__self__, "execution_statuses", execution_statuses)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the scan was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input['DatascanDataArgs']]:
        """
        The data source for DataScan.
        Structure is documented below.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input['DatascanDataArgs']]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter(name="dataProfileResults")
    def data_profile_results(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatascanDataProfileResultArgs']]]]:
        """
        The result of the data profile scan.
        Structure is documented below.
        """
        return pulumi.get(self, "data_profile_results")

    @data_profile_results.setter
    def data_profile_results(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatascanDataProfileResultArgs']]]]):
        pulumi.set(self, "data_profile_results", value)

    @property
    @pulumi.getter(name="dataProfileSpec")
    def data_profile_spec(self) -> Optional[pulumi.Input['DatascanDataProfileSpecArgs']]:
        """
        DataProfileScan related setting.
        Structure is documented below.
        """
        return pulumi.get(self, "data_profile_spec")

    @data_profile_spec.setter
    def data_profile_spec(self, value: Optional[pulumi.Input['DatascanDataProfileSpecArgs']]):
        pulumi.set(self, "data_profile_spec", value)

    @property
    @pulumi.getter(name="dataQualityResults")
    def data_quality_results(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatascanDataQualityResultArgs']]]]:
        """
        The result of the data quality scan.
        Structure is documented below.
        """
        return pulumi.get(self, "data_quality_results")

    @data_quality_results.setter
    def data_quality_results(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatascanDataQualityResultArgs']]]]):
        pulumi.set(self, "data_quality_results", value)

    @property
    @pulumi.getter(name="dataQualitySpec")
    def data_quality_spec(self) -> Optional[pulumi.Input['DatascanDataQualitySpecArgs']]:
        """
        DataQualityScan related setting.
        Structure is documented below.
        """
        return pulumi.get(self, "data_quality_spec")

    @data_quality_spec.setter
    def data_quality_spec(self, value: Optional[pulumi.Input['DatascanDataQualitySpecArgs']]):
        pulumi.set(self, "data_quality_spec", value)

    @property
    @pulumi.getter(name="dataScanId")
    def data_scan_id(self) -> Optional[pulumi.Input[str]]:
        """
        DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
        """
        return pulumi.get(self, "data_scan_id")

    @data_scan_id.setter
    def data_scan_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_scan_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the scan.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        User friendly display name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="executionSpec")
    def execution_spec(self) -> Optional[pulumi.Input['DatascanExecutionSpecArgs']]:
        """
        DataScan execution settings.
        Structure is documented below.
        """
        return pulumi.get(self, "execution_spec")

    @execution_spec.setter
    def execution_spec(self, value: Optional[pulumi.Input['DatascanExecutionSpecArgs']]):
        pulumi.set(self, "execution_spec", value)

    @property
    @pulumi.getter(name="executionStatuses")
    def execution_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatascanExecutionStatusArgs']]]]:
        """
        Status of the data scan execution.
        Structure is documented below.
        """
        return pulumi.get(self, "execution_statuses")

    @execution_statuses.setter
    def execution_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatascanExecutionStatusArgs']]]]):
        pulumi.set(self, "execution_statuses", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        User-defined labels for the scan. A list of key->value pairs.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The location where the data scan should reside.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the field.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        Current state of the DataScan.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The field data type.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[str]]:
        """
        System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the scan was last updated.
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "update_time", value)


class Datascan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data: Optional[pulumi.Input[pulumi.InputType['DatascanDataArgs']]] = None,
                 data_profile_spec: Optional[pulumi.Input[pulumi.InputType['DatascanDataProfileSpecArgs']]] = None,
                 data_quality_spec: Optional[pulumi.Input[pulumi.InputType['DatascanDataQualitySpecArgs']]] = None,
                 data_scan_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 execution_spec: Optional[pulumi.Input[pulumi.InputType['DatascanExecutionSpecArgs']]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Represents a user-visible job which provides the insights for the related data source.

        To get more information about Datascan, see:

        * [API documentation](https://cloud.google.com/dataplex/docs/reference/rest)
        * How-to Guides
            * [Official Documentation](https://cloud.google.com/dataplex/docs)

        ## Example Usage
        ### Dataplex Datascan Basic Profile

        ```python
        import pulumi
        import pulumi_gcp as gcp

        basic_profile = gcp.dataplex.Datascan("basicProfile",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/samples/tables/shakespeare",
            ),
            data_profile_spec=gcp.dataplex.DatascanDataProfileSpecArgs(),
            data_scan_id="tf-test-datascan%{random_suffix}",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    on_demand=gcp.dataplex.DatascanExecutionSpecTriggerOnDemandArgs(),
                ),
            ),
            location="us-central1",
            project="my-project-name")
        ```
        ### Dataplex Datascan Full Profile

        ```python
        import pulumi
        import pulumi_gcp as gcp

        full_profile = gcp.dataplex.Datascan("fullProfile",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/samples/tables/shakespeare",
            ),
            data_profile_spec=gcp.dataplex.DatascanDataProfileSpecArgs(
                row_filter="word_count > 10",
                sampling_percent=80,
            ),
            data_scan_id="tf-test-datascan%{random_suffix}",
            description="Example resource - Full Datascan Profile",
            display_name="Full Datascan Profile",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    schedule=gcp.dataplex.DatascanExecutionSpecTriggerScheduleArgs(
                        cron="TZ=America/New_York 1 1 * * *",
                    ),
                ),
            ),
            labels={
                "author": "billing",
            },
            location="us-central1",
            project="my-project-name")
        ```
        ### Dataplex Datascan Basic Quality

        ```python
        import pulumi
        import pulumi_gcp as gcp

        basic_quality = gcp.dataplex.Datascan("basicQuality",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/samples/tables/shakespeare",
            ),
            data_quality_spec=gcp.dataplex.DatascanDataQualitySpecArgs(
                rules=[gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                    dimension="VALIDITY",
                    table_condition_expectation=gcp.dataplex.DatascanDataQualitySpecRuleTableConditionExpectationArgs(
                        sql_expression="COUNT(*) > 0",
                    ),
                )],
            ),
            data_scan_id="tf-test-datascan%{random_suffix}",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    on_demand=gcp.dataplex.DatascanExecutionSpecTriggerOnDemandArgs(),
                ),
            ),
            location="us-central1",
            project="my-project-name")
        ```
        ### Dataplex Datascan Full Quality

        ```python
        import pulumi
        import pulumi_gcp as gcp

        full_quality = gcp.dataplex.Datascan("fullQuality",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/austin_bikeshare/tables/bikeshare_stations",
            ),
            data_quality_spec=gcp.dataplex.DatascanDataQualitySpecArgs(
                row_filter="station_id > 1000",
                rules=[
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="address",
                        dimension="VALIDITY",
                        non_null_expectation=gcp.dataplex.DatascanDataQualitySpecRuleNonNullExpectationArgs(),
                        threshold=0.99,
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="council_district",
                        dimension="VALIDITY",
                        ignore_null=True,
                        range_expectation=gcp.dataplex.DatascanDataQualitySpecRuleRangeExpectationArgs(
                            max_value="10",
                            min_value="1",
                            strict_max_enabled=False,
                            strict_min_enabled=True,
                        ),
                        threshold=0.9,
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="power_type",
                        dimension="VALIDITY",
                        ignore_null=False,
                        regex_expectation=gcp.dataplex.DatascanDataQualitySpecRuleRegexExpectationArgs(
                            regex=".*solar.*",
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="property_type",
                        dimension="VALIDITY",
                        ignore_null=False,
                        set_expectation=gcp.dataplex.DatascanDataQualitySpecRuleSetExpectationArgs(
                            values=[
                                "sidewalk",
                                "parkland",
                            ],
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="address",
                        dimension="UNIQUENESS",
                        uniqueness_expectation=gcp.dataplex.DatascanDataQualitySpecRuleUniquenessExpectationArgs(),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="number_of_docks",
                        dimension="VALIDITY",
                        statistic_range_expectation=gcp.dataplex.DatascanDataQualitySpecRuleStatisticRangeExpectationArgs(
                            max_value="15",
                            min_value="5",
                            statistic="MEAN",
                            strict_max_enabled=True,
                            strict_min_enabled=True,
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="footprint_length",
                        dimension="VALIDITY",
                        row_condition_expectation=gcp.dataplex.DatascanDataQualitySpecRuleRowConditionExpectationArgs(
                            sql_expression="footprint_length > 0 AND footprint_length <= 10",
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        dimension="VALIDITY",
                        table_condition_expectation=gcp.dataplex.DatascanDataQualitySpecRuleTableConditionExpectationArgs(
                            sql_expression="COUNT(*) > 0",
                        ),
                    ),
                ],
                sampling_percent=5,
            ),
            data_scan_id="tf-test-datascan%{random_suffix}",
            description="Example resource - Full Datascan Quality",
            display_name="Full Datascan Quality",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                field="modified_date",
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    schedule=gcp.dataplex.DatascanExecutionSpecTriggerScheduleArgs(
                        cron="TZ=America/New_York 1 1 * * *",
                    ),
                ),
            ),
            labels={
                "author": "billing",
            },
            location="us-central1",
            project="my-project-name")
        ```

        ## Import

        Datascan can be imported using any of these accepted formats

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default projects/{{project}}/locations/{{location}}/dataScans/{{data_scan_id}}
        ```

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default {{project}}/{{location}}/{{data_scan_id}}
        ```

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default {{location}}/{{data_scan_id}}
        ```

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default {{data_scan_id}}
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['DatascanDataArgs']] data: The data source for DataScan.
               Structure is documented below.
        :param pulumi.Input[pulumi.InputType['DatascanDataProfileSpecArgs']] data_profile_spec: DataProfileScan related setting.
               Structure is documented below.
        :param pulumi.Input[pulumi.InputType['DatascanDataQualitySpecArgs']] data_quality_spec: DataQualityScan related setting.
               Structure is documented below.
        :param pulumi.Input[str] data_scan_id: DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
        :param pulumi.Input[str] description: Description of the scan.
        :param pulumi.Input[str] display_name: User friendly display name.
        :param pulumi.Input[pulumi.InputType['DatascanExecutionSpecArgs']] execution_spec: DataScan execution settings.
               Structure is documented below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: User-defined labels for the scan. A list of key->value pairs.
        :param pulumi.Input[str] location: The location where the data scan should reside.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatascanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Represents a user-visible job which provides the insights for the related data source.

        To get more information about Datascan, see:

        * [API documentation](https://cloud.google.com/dataplex/docs/reference/rest)
        * How-to Guides
            * [Official Documentation](https://cloud.google.com/dataplex/docs)

        ## Example Usage
        ### Dataplex Datascan Basic Profile

        ```python
        import pulumi
        import pulumi_gcp as gcp

        basic_profile = gcp.dataplex.Datascan("basicProfile",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/samples/tables/shakespeare",
            ),
            data_profile_spec=gcp.dataplex.DatascanDataProfileSpecArgs(),
            data_scan_id="tf-test-datascan%{random_suffix}",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    on_demand=gcp.dataplex.DatascanExecutionSpecTriggerOnDemandArgs(),
                ),
            ),
            location="us-central1",
            project="my-project-name")
        ```
        ### Dataplex Datascan Full Profile

        ```python
        import pulumi
        import pulumi_gcp as gcp

        full_profile = gcp.dataplex.Datascan("fullProfile",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/samples/tables/shakespeare",
            ),
            data_profile_spec=gcp.dataplex.DatascanDataProfileSpecArgs(
                row_filter="word_count > 10",
                sampling_percent=80,
            ),
            data_scan_id="tf-test-datascan%{random_suffix}",
            description="Example resource - Full Datascan Profile",
            display_name="Full Datascan Profile",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    schedule=gcp.dataplex.DatascanExecutionSpecTriggerScheduleArgs(
                        cron="TZ=America/New_York 1 1 * * *",
                    ),
                ),
            ),
            labels={
                "author": "billing",
            },
            location="us-central1",
            project="my-project-name")
        ```
        ### Dataplex Datascan Basic Quality

        ```python
        import pulumi
        import pulumi_gcp as gcp

        basic_quality = gcp.dataplex.Datascan("basicQuality",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/samples/tables/shakespeare",
            ),
            data_quality_spec=gcp.dataplex.DatascanDataQualitySpecArgs(
                rules=[gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                    dimension="VALIDITY",
                    table_condition_expectation=gcp.dataplex.DatascanDataQualitySpecRuleTableConditionExpectationArgs(
                        sql_expression="COUNT(*) > 0",
                    ),
                )],
            ),
            data_scan_id="tf-test-datascan%{random_suffix}",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    on_demand=gcp.dataplex.DatascanExecutionSpecTriggerOnDemandArgs(),
                ),
            ),
            location="us-central1",
            project="my-project-name")
        ```
        ### Dataplex Datascan Full Quality

        ```python
        import pulumi
        import pulumi_gcp as gcp

        full_quality = gcp.dataplex.Datascan("fullQuality",
            data=gcp.dataplex.DatascanDataArgs(
                resource="//bigquery.googleapis.com/projects/bigquery-public-data/datasets/austin_bikeshare/tables/bikeshare_stations",
            ),
            data_quality_spec=gcp.dataplex.DatascanDataQualitySpecArgs(
                row_filter="station_id > 1000",
                rules=[
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="address",
                        dimension="VALIDITY",
                        non_null_expectation=gcp.dataplex.DatascanDataQualitySpecRuleNonNullExpectationArgs(),
                        threshold=0.99,
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="council_district",
                        dimension="VALIDITY",
                        ignore_null=True,
                        range_expectation=gcp.dataplex.DatascanDataQualitySpecRuleRangeExpectationArgs(
                            max_value="10",
                            min_value="1",
                            strict_max_enabled=False,
                            strict_min_enabled=True,
                        ),
                        threshold=0.9,
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="power_type",
                        dimension="VALIDITY",
                        ignore_null=False,
                        regex_expectation=gcp.dataplex.DatascanDataQualitySpecRuleRegexExpectationArgs(
                            regex=".*solar.*",
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="property_type",
                        dimension="VALIDITY",
                        ignore_null=False,
                        set_expectation=gcp.dataplex.DatascanDataQualitySpecRuleSetExpectationArgs(
                            values=[
                                "sidewalk",
                                "parkland",
                            ],
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="address",
                        dimension="UNIQUENESS",
                        uniqueness_expectation=gcp.dataplex.DatascanDataQualitySpecRuleUniquenessExpectationArgs(),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="number_of_docks",
                        dimension="VALIDITY",
                        statistic_range_expectation=gcp.dataplex.DatascanDataQualitySpecRuleStatisticRangeExpectationArgs(
                            max_value="15",
                            min_value="5",
                            statistic="MEAN",
                            strict_max_enabled=True,
                            strict_min_enabled=True,
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        column="footprint_length",
                        dimension="VALIDITY",
                        row_condition_expectation=gcp.dataplex.DatascanDataQualitySpecRuleRowConditionExpectationArgs(
                            sql_expression="footprint_length > 0 AND footprint_length <= 10",
                        ),
                    ),
                    gcp.dataplex.DatascanDataQualitySpecRuleArgs(
                        dimension="VALIDITY",
                        table_condition_expectation=gcp.dataplex.DatascanDataQualitySpecRuleTableConditionExpectationArgs(
                            sql_expression="COUNT(*) > 0",
                        ),
                    ),
                ],
                sampling_percent=5,
            ),
            data_scan_id="tf-test-datascan%{random_suffix}",
            description="Example resource - Full Datascan Quality",
            display_name="Full Datascan Quality",
            execution_spec=gcp.dataplex.DatascanExecutionSpecArgs(
                field="modified_date",
                trigger=gcp.dataplex.DatascanExecutionSpecTriggerArgs(
                    schedule=gcp.dataplex.DatascanExecutionSpecTriggerScheduleArgs(
                        cron="TZ=America/New_York 1 1 * * *",
                    ),
                ),
            ),
            labels={
                "author": "billing",
            },
            location="us-central1",
            project="my-project-name")
        ```

        ## Import

        Datascan can be imported using any of these accepted formats

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default projects/{{project}}/locations/{{location}}/dataScans/{{data_scan_id}}
        ```

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default {{project}}/{{location}}/{{data_scan_id}}
        ```

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default {{location}}/{{data_scan_id}}
        ```

        ```sh
         $ pulumi import gcp:dataplex/datascan:Datascan default {{data_scan_id}}
        ```

        :param str resource_name: The name of the resource.
        :param DatascanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatascanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data: Optional[pulumi.Input[pulumi.InputType['DatascanDataArgs']]] = None,
                 data_profile_spec: Optional[pulumi.Input[pulumi.InputType['DatascanDataProfileSpecArgs']]] = None,
                 data_quality_spec: Optional[pulumi.Input[pulumi.InputType['DatascanDataQualitySpecArgs']]] = None,
                 data_scan_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 execution_spec: Optional[pulumi.Input[pulumi.InputType['DatascanExecutionSpecArgs']]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatascanArgs.__new__(DatascanArgs)

            if data is None and not opts.urn:
                raise TypeError("Missing required property 'data'")
            __props__.__dict__["data"] = data
            __props__.__dict__["data_profile_spec"] = data_profile_spec
            __props__.__dict__["data_quality_spec"] = data_quality_spec
            if data_scan_id is None and not opts.urn:
                raise TypeError("Missing required property 'data_scan_id'")
            __props__.__dict__["data_scan_id"] = data_scan_id
            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            if execution_spec is None and not opts.urn:
                raise TypeError("Missing required property 'execution_spec'")
            __props__.__dict__["execution_spec"] = execution_spec
            __props__.__dict__["labels"] = labels
            if location is None and not opts.urn:
                raise TypeError("Missing required property 'location'")
            __props__.__dict__["location"] = location
            __props__.__dict__["project"] = project
            __props__.__dict__["create_time"] = None
            __props__.__dict__["data_profile_results"] = None
            __props__.__dict__["data_quality_results"] = None
            __props__.__dict__["execution_statuses"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["uid"] = None
            __props__.__dict__["update_time"] = None
        super(Datascan, __self__).__init__(
            'gcp:dataplex/datascan:Datascan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            data: Optional[pulumi.Input[pulumi.InputType['DatascanDataArgs']]] = None,
            data_profile_results: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatascanDataProfileResultArgs']]]]] = None,
            data_profile_spec: Optional[pulumi.Input[pulumi.InputType['DatascanDataProfileSpecArgs']]] = None,
            data_quality_results: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatascanDataQualityResultArgs']]]]] = None,
            data_quality_spec: Optional[pulumi.Input[pulumi.InputType['DatascanDataQualitySpecArgs']]] = None,
            data_scan_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            execution_spec: Optional[pulumi.Input[pulumi.InputType['DatascanExecutionSpecArgs']]] = None,
            execution_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatascanExecutionStatusArgs']]]]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            location: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None,
            uid: Optional[pulumi.Input[str]] = None,
            update_time: Optional[pulumi.Input[str]] = None) -> 'Datascan':
        """
        Get an existing Datascan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The time when the scan was created.
        :param pulumi.Input[pulumi.InputType['DatascanDataArgs']] data: The data source for DataScan.
               Structure is documented below.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatascanDataProfileResultArgs']]]] data_profile_results: The result of the data profile scan.
               Structure is documented below.
        :param pulumi.Input[pulumi.InputType['DatascanDataProfileSpecArgs']] data_profile_spec: DataProfileScan related setting.
               Structure is documented below.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatascanDataQualityResultArgs']]]] data_quality_results: The result of the data quality scan.
               Structure is documented below.
        :param pulumi.Input[pulumi.InputType['DatascanDataQualitySpecArgs']] data_quality_spec: DataQualityScan related setting.
               Structure is documented below.
        :param pulumi.Input[str] data_scan_id: DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
        :param pulumi.Input[str] description: Description of the scan.
        :param pulumi.Input[str] display_name: User friendly display name.
        :param pulumi.Input[pulumi.InputType['DatascanExecutionSpecArgs']] execution_spec: DataScan execution settings.
               Structure is documented below.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatascanExecutionStatusArgs']]]] execution_statuses: Status of the data scan execution.
               Structure is documented below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: User-defined labels for the scan. A list of key->value pairs.
        :param pulumi.Input[str] location: The location where the data scan should reside.
        :param pulumi.Input[str] name: The name of the field.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        :param pulumi.Input[str] state: Current state of the DataScan.
        :param pulumi.Input[str] type: The field data type.
        :param pulumi.Input[str] uid: System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.
        :param pulumi.Input[str] update_time: The time when the scan was last updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatascanState.__new__(_DatascanState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["data"] = data
        __props__.__dict__["data_profile_results"] = data_profile_results
        __props__.__dict__["data_profile_spec"] = data_profile_spec
        __props__.__dict__["data_quality_results"] = data_quality_results
        __props__.__dict__["data_quality_spec"] = data_quality_spec
        __props__.__dict__["data_scan_id"] = data_scan_id
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["execution_spec"] = execution_spec
        __props__.__dict__["execution_statuses"] = execution_statuses
        __props__.__dict__["labels"] = labels
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["state"] = state
        __props__.__dict__["type"] = type
        __props__.__dict__["uid"] = uid
        __props__.__dict__["update_time"] = update_time
        return Datascan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The time when the scan was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def data(self) -> pulumi.Output['outputs.DatascanData']:
        """
        The data source for DataScan.
        Structure is documented below.
        """
        return pulumi.get(self, "data")

    @property
    @pulumi.getter(name="dataProfileResults")
    def data_profile_results(self) -> pulumi.Output[Sequence['outputs.DatascanDataProfileResult']]:
        """
        The result of the data profile scan.
        Structure is documented below.
        """
        return pulumi.get(self, "data_profile_results")

    @property
    @pulumi.getter(name="dataProfileSpec")
    def data_profile_spec(self) -> pulumi.Output[Optional['outputs.DatascanDataProfileSpec']]:
        """
        DataProfileScan related setting.
        Structure is documented below.
        """
        return pulumi.get(self, "data_profile_spec")

    @property
    @pulumi.getter(name="dataQualityResults")
    def data_quality_results(self) -> pulumi.Output[Sequence['outputs.DatascanDataQualityResult']]:
        """
        The result of the data quality scan.
        Structure is documented below.
        """
        return pulumi.get(self, "data_quality_results")

    @property
    @pulumi.getter(name="dataQualitySpec")
    def data_quality_spec(self) -> pulumi.Output[Optional['outputs.DatascanDataQualitySpec']]:
        """
        DataQualityScan related setting.
        Structure is documented below.
        """
        return pulumi.get(self, "data_quality_spec")

    @property
    @pulumi.getter(name="dataScanId")
    def data_scan_id(self) -> pulumi.Output[str]:
        """
        DataScan identifier. Must contain only lowercase letters, numbers and hyphens. Must start with a letter. Must end with a number or a letter.
        """
        return pulumi.get(self, "data_scan_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the scan.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[str]]:
        """
        User friendly display name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="executionSpec")
    def execution_spec(self) -> pulumi.Output['outputs.DatascanExecutionSpec']:
        """
        DataScan execution settings.
        Structure is documented below.
        """
        return pulumi.get(self, "execution_spec")

    @property
    @pulumi.getter(name="executionStatuses")
    def execution_statuses(self) -> pulumi.Output[Sequence['outputs.DatascanExecutionStatus']]:
        """
        Status of the data scan execution.
        Structure is documented below.
        """
        return pulumi.get(self, "execution_statuses")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        User-defined labels for the scan. A list of key->value pairs.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        The location where the data scan should reside.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the field.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        Current state of the DataScan.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The field data type.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[str]:
        """
        System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[str]:
        """
        The time when the scan was last updated.
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DocumentAiWarehouseDocumentSchemaArgs', 'DocumentAiWarehouseDocumentSchema']

@pulumi.input_type
class DocumentAiWarehouseDocumentSchemaArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[str],
                 location: pulumi.Input[str],
                 project_number: pulumi.Input[str],
                 property_definitions: pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]],
                 document_is_folder: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a DocumentAiWarehouseDocumentSchema resource.
        :param pulumi.Input[str] display_name: Name of the schema given by the user.
        :param pulumi.Input[str] location: The location of the resource.
        :param pulumi.Input[str] project_number: The unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]] property_definitions: Defines the metadata for a schema property.
               Structure is documented below.
        :param pulumi.Input[bool] document_is_folder: Tells whether the document is a folder or a typical document.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "location", location)
        pulumi.set(__self__, "project_number", project_number)
        pulumi.set(__self__, "property_definitions", property_definitions)
        if document_is_folder is not None:
            pulumi.set(__self__, "document_is_folder", document_is_folder)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        Name of the schema given by the user.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def location(self) -> pulumi.Input[str]:
        """
        The location of the resource.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: pulumi.Input[str]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="projectNumber")
    def project_number(self) -> pulumi.Input[str]:
        """
        The unique identifier of the project.
        """
        return pulumi.get(self, "project_number")

    @project_number.setter
    def project_number(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_number", value)

    @property
    @pulumi.getter(name="propertyDefinitions")
    def property_definitions(self) -> pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]:
        """
        Defines the metadata for a schema property.
        Structure is documented below.
        """
        return pulumi.get(self, "property_definitions")

    @property_definitions.setter
    def property_definitions(self, value: pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]):
        pulumi.set(self, "property_definitions", value)

    @property
    @pulumi.getter(name="documentIsFolder")
    def document_is_folder(self) -> Optional[pulumi.Input[bool]]:
        """
        Tells whether the document is a folder or a typical document.
        """
        return pulumi.get(self, "document_is_folder")

    @document_is_folder.setter
    def document_is_folder(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "document_is_folder", value)


@pulumi.input_type
class _DocumentAiWarehouseDocumentSchemaState:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[str]] = None,
                 document_is_folder: Optional[pulumi.Input[bool]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_number: Optional[pulumi.Input[str]] = None,
                 property_definitions: Optional[pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]] = None):
        """
        Input properties used for looking up and filtering DocumentAiWarehouseDocumentSchema resources.
        :param pulumi.Input[str] display_name: Name of the schema given by the user.
        :param pulumi.Input[bool] document_is_folder: Tells whether the document is a folder or a typical document.
        :param pulumi.Input[str] location: The location of the resource.
        :param pulumi.Input[str] name: The name of the metadata property.
               
               (Optional)
               The schema name in the source.
               
               (Required)
               The name of the metadata property.
               
               (Optional)
               The schema name in the source.
        :param pulumi.Input[str] project_number: The unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]] property_definitions: Defines the metadata for a schema property.
               Structure is documented below.
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if document_is_folder is not None:
            pulumi.set(__self__, "document_is_folder", document_is_folder)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_number is not None:
            pulumi.set(__self__, "project_number", project_number)
        if property_definitions is not None:
            pulumi.set(__self__, "property_definitions", property_definitions)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the schema given by the user.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="documentIsFolder")
    def document_is_folder(self) -> Optional[pulumi.Input[bool]]:
        """
        Tells whether the document is a folder or a typical document.
        """
        return pulumi.get(self, "document_is_folder")

    @document_is_folder.setter
    def document_is_folder(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "document_is_folder", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The location of the resource.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the metadata property.

        (Optional)
        The schema name in the source.

        (Required)
        The name of the metadata property.

        (Optional)
        The schema name in the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectNumber")
    def project_number(self) -> Optional[pulumi.Input[str]]:
        """
        The unique identifier of the project.
        """
        return pulumi.get(self, "project_number")

    @project_number.setter
    def project_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_number", value)

    @property
    @pulumi.getter(name="propertyDefinitions")
    def property_definitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]]:
        """
        Defines the metadata for a schema property.
        Structure is documented below.
        """
        return pulumi.get(self, "property_definitions")

    @property_definitions.setter
    def property_definitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]]):
        pulumi.set(self, "property_definitions", value)


class DocumentAiWarehouseDocumentSchema(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 document_is_folder: Optional[pulumi.Input[bool]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 project_number: Optional[pulumi.Input[str]] = None,
                 property_definitions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]]] = None,
                 __props__=None):
        """
        A document schema is used to define document structure.

        To get more information about DocumentSchema, see:

        * [API documentation](https://cloud.google.com/document-warehouse/docs/reference/rest/v1/projects.locations.documentSchemas)
        * How-to Guides
            * [Official Documentation](https://cloud.google.com/document-warehouse/docs/manage-document-schemas)

        ## Example Usage
        ### Document Ai Warehouse Document Schema Text

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_text = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleText",
            project_number=project.number,
            display_name="test-property-text",
            location="us",
            document_is_folder=False,
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop3",
                display_name="propdisp3",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                text_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionTextTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Integer

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_integer = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleInteger",
            project_number=project.number,
            display_name="test-property-integer",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop1",
                display_name="propdisp1",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                integer_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionIntegerTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Float

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_float = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleFloat",
            project_number=project.number,
            display_name="test-property-float",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop2",
                display_name="propdisp2",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                float_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionFloatTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Property

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_property = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleProperty",
            project_number=project.number,
            display_name="test-property-property",
            location="us",
            document_is_folder=False,
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop8",
                display_name="propdisp8",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                property_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsArgs(
                    property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionArgs(
                        name="prop8_nested",
                        display_name="propdisp8_nested",
                        is_repeatable=False,
                        is_filterable=True,
                        is_searchable=True,
                        is_metadata=False,
                        is_required=False,
                        retrieval_importance="HIGHEST",
                        schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionSchemaSourceArgs(
                            name="dummy_source_nested",
                            processor_type="dummy_processor_nested",
                        )],
                        text_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionTextTypeOptionsArgs(),
                    )],
                ),
            )])
        ```
        ### Document Ai Warehouse Document Schema Property Enum

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_property_enum = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("examplePropertyEnum",
            project_number=project.number,
            display_name="test-property-property",
            location="us",
            document_is_folder=False,
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop8",
                display_name="propdisp8",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                property_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsArgs(
                    property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionArgs(
                        name="prop8_nested",
                        display_name="propdisp8_nested",
                        is_repeatable=False,
                        is_filterable=True,
                        is_searchable=True,
                        is_metadata=False,
                        is_required=False,
                        retrieval_importance="HIGHEST",
                        schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionSchemaSourceArgs(
                            name="dummy_source_nested",
                            processor_type="dummy_processor_nested",
                        )],
                        enum_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionEnumTypeOptionsArgs(
                            possible_values=[
                                "M",
                                "F",
                                "X",
                            ],
                            validation_check_disabled=False,
                        ),
                    )],
                ),
            )])
        ```
        ### Document Ai Warehouse Document Schema Enum

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_enum = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleEnum",
            project_number=project.number,
            display_name="test-property-enum",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop6",
                display_name="propdisp6",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                enum_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionEnumTypeOptionsArgs(
                    possible_values=[
                        "M",
                        "F",
                        "X",
                    ],
                    validation_check_disabled=False,
                ),
            )])
        ```
        ### Document Ai Warehouse Document Schema Map

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_map = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleMap",
            project_number=project.number,
            display_name="test-property-map",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop4",
                display_name="propdisp4",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                map_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionMapTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Datetime

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_datetime = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleDatetime",
            project_number=project.number,
            display_name="test-property-date_time",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop7",
                display_name="propdisp7",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                date_time_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionDateTimeTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Timestamp

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_timestamp = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleTimestamp",
            project_number=project.number,
            display_name="test-property-timestamp",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop5",
                display_name="propdisp5",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                timestamp_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionTimestampTypeOptionsArgs(),
            )])
        ```

        ## Import

        DocumentSchema can be imported using any of these accepted formats

        ```sh
         $ pulumi import gcp:essentialcontacts/documentAiWarehouseDocumentSchema:DocumentAiWarehouseDocumentSchema default projects/{{project_number}}/locations/{{location}}/documentSchemas/{{name}}
        ```

        ```sh
         $ pulumi import gcp:essentialcontacts/documentAiWarehouseDocumentSchema:DocumentAiWarehouseDocumentSchema default {{project_number}}/{{location}}/{{name}}
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] display_name: Name of the schema given by the user.
        :param pulumi.Input[bool] document_is_folder: Tells whether the document is a folder or a typical document.
        :param pulumi.Input[str] location: The location of the resource.
        :param pulumi.Input[str] project_number: The unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]] property_definitions: Defines the metadata for a schema property.
               Structure is documented below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DocumentAiWarehouseDocumentSchemaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A document schema is used to define document structure.

        To get more information about DocumentSchema, see:

        * [API documentation](https://cloud.google.com/document-warehouse/docs/reference/rest/v1/projects.locations.documentSchemas)
        * How-to Guides
            * [Official Documentation](https://cloud.google.com/document-warehouse/docs/manage-document-schemas)

        ## Example Usage
        ### Document Ai Warehouse Document Schema Text

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_text = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleText",
            project_number=project.number,
            display_name="test-property-text",
            location="us",
            document_is_folder=False,
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop3",
                display_name="propdisp3",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                text_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionTextTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Integer

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_integer = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleInteger",
            project_number=project.number,
            display_name="test-property-integer",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop1",
                display_name="propdisp1",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                integer_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionIntegerTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Float

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_float = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleFloat",
            project_number=project.number,
            display_name="test-property-float",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop2",
                display_name="propdisp2",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                float_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionFloatTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Property

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_property = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleProperty",
            project_number=project.number,
            display_name="test-property-property",
            location="us",
            document_is_folder=False,
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop8",
                display_name="propdisp8",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                property_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsArgs(
                    property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionArgs(
                        name="prop8_nested",
                        display_name="propdisp8_nested",
                        is_repeatable=False,
                        is_filterable=True,
                        is_searchable=True,
                        is_metadata=False,
                        is_required=False,
                        retrieval_importance="HIGHEST",
                        schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionSchemaSourceArgs(
                            name="dummy_source_nested",
                            processor_type="dummy_processor_nested",
                        )],
                        text_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionTextTypeOptionsArgs(),
                    )],
                ),
            )])
        ```
        ### Document Ai Warehouse Document Schema Property Enum

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_property_enum = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("examplePropertyEnum",
            project_number=project.number,
            display_name="test-property-property",
            location="us",
            document_is_folder=False,
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop8",
                display_name="propdisp8",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                property_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsArgs(
                    property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionArgs(
                        name="prop8_nested",
                        display_name="propdisp8_nested",
                        is_repeatable=False,
                        is_filterable=True,
                        is_searchable=True,
                        is_metadata=False,
                        is_required=False,
                        retrieval_importance="HIGHEST",
                        schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionSchemaSourceArgs(
                            name="dummy_source_nested",
                            processor_type="dummy_processor_nested",
                        )],
                        enum_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionPropertyTypeOptionsPropertyDefinitionEnumTypeOptionsArgs(
                            possible_values=[
                                "M",
                                "F",
                                "X",
                            ],
                            validation_check_disabled=False,
                        ),
                    )],
                ),
            )])
        ```
        ### Document Ai Warehouse Document Schema Enum

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_enum = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleEnum",
            project_number=project.number,
            display_name="test-property-enum",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop6",
                display_name="propdisp6",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                enum_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionEnumTypeOptionsArgs(
                    possible_values=[
                        "M",
                        "F",
                        "X",
                    ],
                    validation_check_disabled=False,
                ),
            )])
        ```
        ### Document Ai Warehouse Document Schema Map

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_map = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleMap",
            project_number=project.number,
            display_name="test-property-map",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop4",
                display_name="propdisp4",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                map_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionMapTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Datetime

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_datetime = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleDatetime",
            project_number=project.number,
            display_name="test-property-date_time",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop7",
                display_name="propdisp7",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                date_time_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionDateTimeTypeOptionsArgs(),
            )])
        ```
        ### Document Ai Warehouse Document Schema Timestamp

        ```python
        import pulumi
        import pulumi_gcp as gcp

        project = gcp.organizations.get_project()
        example_timestamp = gcp.essentialcontacts.DocumentAiWarehouseDocumentSchema("exampleTimestamp",
            project_number=project.number,
            display_name="test-property-timestamp",
            location="us",
            property_definitions=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs(
                name="prop5",
                display_name="propdisp5",
                is_repeatable=False,
                is_filterable=True,
                is_searchable=True,
                is_metadata=False,
                is_required=False,
                retrieval_importance="HIGHEST",
                schema_sources=[gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionSchemaSourceArgs(
                    name="dummy_source",
                    processor_type="dummy_processor",
                )],
                timestamp_type_options=gcp.essentialcontacts.DocumentAiWarehouseDocumentSchemaPropertyDefinitionTimestampTypeOptionsArgs(),
            )])
        ```

        ## Import

        DocumentSchema can be imported using any of these accepted formats

        ```sh
         $ pulumi import gcp:essentialcontacts/documentAiWarehouseDocumentSchema:DocumentAiWarehouseDocumentSchema default projects/{{project_number}}/locations/{{location}}/documentSchemas/{{name}}
        ```

        ```sh
         $ pulumi import gcp:essentialcontacts/documentAiWarehouseDocumentSchema:DocumentAiWarehouseDocumentSchema default {{project_number}}/{{location}}/{{name}}
        ```

        :param str resource_name: The name of the resource.
        :param DocumentAiWarehouseDocumentSchemaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DocumentAiWarehouseDocumentSchemaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 document_is_folder: Optional[pulumi.Input[bool]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 project_number: Optional[pulumi.Input[str]] = None,
                 property_definitions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DocumentAiWarehouseDocumentSchemaArgs.__new__(DocumentAiWarehouseDocumentSchemaArgs)

            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["document_is_folder"] = document_is_folder
            if location is None and not opts.urn:
                raise TypeError("Missing required property 'location'")
            __props__.__dict__["location"] = location
            if project_number is None and not opts.urn:
                raise TypeError("Missing required property 'project_number'")
            __props__.__dict__["project_number"] = project_number
            if property_definitions is None and not opts.urn:
                raise TypeError("Missing required property 'property_definitions'")
            __props__.__dict__["property_definitions"] = property_definitions
            __props__.__dict__["name"] = None
        super(DocumentAiWarehouseDocumentSchema, __self__).__init__(
            'gcp:essentialcontacts/documentAiWarehouseDocumentSchema:DocumentAiWarehouseDocumentSchema',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            document_is_folder: Optional[pulumi.Input[bool]] = None,
            location: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project_number: Optional[pulumi.Input[str]] = None,
            property_definitions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]]] = None) -> 'DocumentAiWarehouseDocumentSchema':
        """
        Get an existing DocumentAiWarehouseDocumentSchema resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] display_name: Name of the schema given by the user.
        :param pulumi.Input[bool] document_is_folder: Tells whether the document is a folder or a typical document.
        :param pulumi.Input[str] location: The location of the resource.
        :param pulumi.Input[str] name: The name of the metadata property.
               
               (Optional)
               The schema name in the source.
               
               (Required)
               The name of the metadata property.
               
               (Optional)
               The schema name in the source.
        :param pulumi.Input[str] project_number: The unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DocumentAiWarehouseDocumentSchemaPropertyDefinitionArgs']]]] property_definitions: Defines the metadata for a schema property.
               Structure is documented below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DocumentAiWarehouseDocumentSchemaState.__new__(_DocumentAiWarehouseDocumentSchemaState)

        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["document_is_folder"] = document_is_folder
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["project_number"] = project_number
        __props__.__dict__["property_definitions"] = property_definitions
        return DocumentAiWarehouseDocumentSchema(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        Name of the schema given by the user.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="documentIsFolder")
    def document_is_folder(self) -> pulumi.Output[Optional[bool]]:
        """
        Tells whether the document is a folder or a typical document.
        """
        return pulumi.get(self, "document_is_folder")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        The location of the resource.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the metadata property.

        (Optional)
        The schema name in the source.

        (Required)
        The name of the metadata property.

        (Optional)
        The schema name in the source.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectNumber")
    def project_number(self) -> pulumi.Output[str]:
        """
        The unique identifier of the project.
        """
        return pulumi.get(self, "project_number")

    @property
    @pulumi.getter(name="propertyDefinitions")
    def property_definitions(self) -> pulumi.Output[Sequence['outputs.DocumentAiWarehouseDocumentSchemaPropertyDefinition']]:
        """
        Defines the metadata for a schema property.
        Structure is documented below.
        """
        return pulumi.get(self, "property_definitions")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSecretVersionAccessResult',
    'AwaitableGetSecretVersionAccessResult',
    'get_secret_version_access',
    'get_secret_version_access_output',
]

@pulumi.output_type
class GetSecretVersionAccessResult:
    """
    A collection of values returned by getSecretVersionAccess.
    """
    def __init__(__self__, id=None, name=None, project=None, secret=None, secret_data=None, version=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if secret and not isinstance(secret, str):
            raise TypeError("Expected argument 'secret' to be a str")
        pulumi.set(__self__, "secret", secret)
        if secret_data and not isinstance(secret_data, str):
            raise TypeError("Expected argument 'secret_data' to be a str")
        pulumi.set(__self__, "secret_data", secret_data)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The resource name of the SecretVersion. Format:
        `projects/{{project}}/secrets/{{secret_id}}/versions/{{version}}`
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def secret(self) -> str:
        return pulumi.get(self, "secret")

    @property
    @pulumi.getter(name="secretData")
    def secret_data(self) -> str:
        """
        The secret data. No larger than 64KiB.
        """
        return pulumi.get(self, "secret_data")

    @property
    @pulumi.getter
    def version(self) -> str:
        return pulumi.get(self, "version")


class AwaitableGetSecretVersionAccessResult(GetSecretVersionAccessResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecretVersionAccessResult(
            id=self.id,
            name=self.name,
            project=self.project,
            secret=self.secret,
            secret_data=self.secret_data,
            version=self.version)


def get_secret_version_access(project: Optional[str] = None,
                              secret: Optional[str] = None,
                              version: Optional[str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecretVersionAccessResult:
    """
    Get the value from a Secret Manager secret version. This is similar to the secretmanager.SecretVersion datasource, but it only requires the [Secret Manager Secret Accessor](https://cloud.google.com/secret-manager/docs/access-control#secretmanager.secretAccessor) role. For more information see the [official documentation](https://cloud.google.com/secret-manager/docs/) and [API](https://cloud.google.com/secret-manager/docs/reference/rest/v1/projects.secrets.versions/access).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gcp as gcp

    basic = gcp.secretmanager.get_secret_version_access(secret="my-secret")
    ```


    :param str project: The project to get the secret version for. If it
           is not provided, the provider project is used.
    :param str secret: The secret to get the secret version for.
    :param str version: The version of the secret to get. If it
           is not provided, the latest version is retrieved.
    """
    __args__ = dict()
    __args__['project'] = project
    __args__['secret'] = secret
    __args__['version'] = version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gcp:secretmanager/getSecretVersionAccess:getSecretVersionAccess', __args__, opts=opts, typ=GetSecretVersionAccessResult).value

    return AwaitableGetSecretVersionAccessResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        project=pulumi.get(__ret__, 'project'),
        secret=pulumi.get(__ret__, 'secret'),
        secret_data=pulumi.get(__ret__, 'secret_data'),
        version=pulumi.get(__ret__, 'version'))


@_utilities.lift_output_func(get_secret_version_access)
def get_secret_version_access_output(project: Optional[pulumi.Input[Optional[str]]] = None,
                                     secret: Optional[pulumi.Input[str]] = None,
                                     version: Optional[pulumi.Input[Optional[str]]] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSecretVersionAccessResult]:
    """
    Get the value from a Secret Manager secret version. This is similar to the secretmanager.SecretVersion datasource, but it only requires the [Secret Manager Secret Accessor](https://cloud.google.com/secret-manager/docs/access-control#secretmanager.secretAccessor) role. For more information see the [official documentation](https://cloud.google.com/secret-manager/docs/) and [API](https://cloud.google.com/secret-manager/docs/reference/rest/v1/projects.secrets.versions/access).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gcp as gcp

    basic = gcp.secretmanager.get_secret_version_access(secret="my-secret")
    ```


    :param str project: The project to get the secret version for. If it
           is not provided, the provider project is used.
    :param str secret: The secret to get the secret version for.
    :param str version: The version of the secret to get. If it
           is not provided, the latest version is retrieved.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ProjectInfoArgs', 'ProjectInfo']

@pulumi.input_type
class ProjectInfoArgs:
    def __init__(__self__, *,
                 billing_account: pulumi.Input[str],
                 project: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProjectInfo resource.
        :param pulumi.Input[str] billing_account: The ID of the billing account associated with the project, if
               any. Set to empty string to disable billing for the project.
               For example, `"012345-567890-ABCDEF"` or `""`.
               
               
               - - -
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        pulumi.set(__self__, "billing_account", billing_account)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="billingAccount")
    def billing_account(self) -> pulumi.Input[str]:
        """
        The ID of the billing account associated with the project, if
        any. Set to empty string to disable billing for the project.
        For example, `"012345-567890-ABCDEF"` or `""`.


        - - -
        """
        return pulumi.get(self, "billing_account")

    @billing_account.setter
    def billing_account(self, value: pulumi.Input[str]):
        pulumi.set(self, "billing_account", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _ProjectInfoState:
    def __init__(__self__, *,
                 billing_account: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectInfo resources.
        :param pulumi.Input[str] billing_account: The ID of the billing account associated with the project, if
               any. Set to empty string to disable billing for the project.
               For example, `"012345-567890-ABCDEF"` or `""`.
               
               
               - - -
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        if billing_account is not None:
            pulumi.set(__self__, "billing_account", billing_account)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="billingAccount")
    def billing_account(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the billing account associated with the project, if
        any. Set to empty string to disable billing for the project.
        For example, `"012345-567890-ABCDEF"` or `""`.


        - - -
        """
        return pulumi.get(self, "billing_account")

    @billing_account.setter
    def billing_account(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "billing_account", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


class ProjectInfo(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 billing_account: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Billing information for a project.

        To get more information about ProjectInfo, see:

        * [API documentation](https://cloud.google.com/billing/docs/reference/rest/v1/projects)
        * How-to Guides
            * [Enable, disable, or change billing for a project](https://cloud.google.com/billing/docs/how-to/modify-project)

        ## Example Usage

        ## Import

        ProjectInfo can be imported using any of these accepted formats

        ```sh
         $ pulumi import gcp:billing/projectInfo:ProjectInfo default projects/{{project}}
        ```

        ```sh
         $ pulumi import gcp:billing/projectInfo:ProjectInfo default {{project}}
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] billing_account: The ID of the billing account associated with the project, if
               any. Set to empty string to disable billing for the project.
               For example, `"012345-567890-ABCDEF"` or `""`.
               
               
               - - -
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectInfoArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Billing information for a project.

        To get more information about ProjectInfo, see:

        * [API documentation](https://cloud.google.com/billing/docs/reference/rest/v1/projects)
        * How-to Guides
            * [Enable, disable, or change billing for a project](https://cloud.google.com/billing/docs/how-to/modify-project)

        ## Example Usage

        ## Import

        ProjectInfo can be imported using any of these accepted formats

        ```sh
         $ pulumi import gcp:billing/projectInfo:ProjectInfo default projects/{{project}}
        ```

        ```sh
         $ pulumi import gcp:billing/projectInfo:ProjectInfo default {{project}}
        ```

        :param str resource_name: The name of the resource.
        :param ProjectInfoArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectInfoArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 billing_account: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectInfoArgs.__new__(ProjectInfoArgs)

            if billing_account is None and not opts.urn:
                raise TypeError("Missing required property 'billing_account'")
            __props__.__dict__["billing_account"] = billing_account
            __props__.__dict__["project"] = project
        super(ProjectInfo, __self__).__init__(
            'gcp:billing/projectInfo:ProjectInfo',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            billing_account: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'ProjectInfo':
        """
        Get an existing ProjectInfo resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] billing_account: The ID of the billing account associated with the project, if
               any. Set to empty string to disable billing for the project.
               For example, `"012345-567890-ABCDEF"` or `""`.
               
               
               - - -
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectInfoState.__new__(_ProjectInfoState)

        __props__.__dict__["billing_account"] = billing_account
        __props__.__dict__["project"] = project
        return ProjectInfo(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="billingAccount")
    def billing_account(self) -> pulumi.Output[str]:
        """
        The ID of the billing account associated with the project, if
        any. Set to empty string to disable billing for the project.
        For example, `"012345-567890-ABCDEF"` or `""`.


        - - -
        """
        return pulumi.get(self, "billing_account")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

